package com.goldenwater.slaj.ttsa.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.ttsa.domain.BisTtsaDesignExamRel;

@Mapper
public interface BisTtsaDesignExamRelMapper {
    BisTtsaDesignExamRel selectBisTtsaDesignExamRelByGuid(String guid);
    List<BisTtsaDesignExamRel> selectBisTtsaDesignExamRelList(BisTtsaDesignExamRel bisTtsaDesignExamRel);
    int insertBisTtsaDesignExamRel(BisTtsaDesignExamRel bisTtsaDesignExamRel);
    int updateBisTtsaDesignExamRel(BisTtsaDesignExamRel bisTtsaDesignExamRel);
    int deleteBisTtsaDesignExamRelByGuid(String guid);
    int deleteBisTtsaDesignExamRelByGuids(String[] guids);
}
